@@ -22,12 +22,11 @@ def _unpack_tar(tarpath: str, extract_dir: str) -> str:
 
     This expects the `extract_dir` to exist.
 
-    Raises
-
+    Raises:
         shutil.ReadError in case of issue uncompressing the archive (tarpath
         does not exist, extract_dir does not exist, etc...)
 
-    Returns
+    Returns:
         full path to the uncompressed directory.
 
     """
@@ -40,6 +39,29 @@ def _unpack_tar(tarpath: str, extract_dir: str) -> str:
         )
 
 
+def _unpack_zip(zippath: str, extract_dir: str) -> str:
+    """Unpack zip files unsupported by the standard python library, for instance
+    those with legacy compression type 6 (implode).
+
+    This expects the `extract_dir` to exist.
+
+    Raises:
+        shutil.ReadError in case of issue uncompressing the archive (zippath
+        does not exist, extract_dir does not exist, etc...)
+
+    Returns:
+        full path to the uncompressed directory.
+
+    """
+    try:
+        run(["unzip", "-d", extract_dir, zippath], check=True)
+        return extract_dir
+    except Exception as e:
+        raise shutil.ReadError(
+            f"Unable to uncompress {zippath} to {extract_dir}. Reason: {e}"
+        )
+
+
 def register_new_archive_formats():
     """Register new archive formats to uncompress
 
@@ -59,19 +81,23 @@ def uncompress(tarpath: str, dest: str):
 
     Args:
         tarpath: path to tarball to uncompress
-        dest: the destination folder where to uncompress the tarball
-
-    Returns:
-        The nature of the tarball, zip or tar.
+        dest: the destination folder where to uncompress the tarball,
+            it will be created if it does not exist
 
     Raises:
         ValueError when a problem occurs during unpacking
 
     """
     try:
+        os.makedirs(dest, exist_ok=True)
         shutil.unpack_archive(tarpath, extract_dir=dest)
     except shutil.ReadError as e:
         raise ValueError(f"Problem during unpacking {tarpath}. Reason: {e}")
+    except NotImplementedError:
+        if tarpath.endswith(".zip"):
+            _unpack_zip(tarpath, dest)
+        else:
+            raise
 
     normalize_permissions(dest)
 
